@@ -22,6 +22,7 @@ BACKUP_ALIASES = ('backup' , 'create-copy')
 RESTORE_ALIASES = ('restore' , 'reinstate' , 'restore-wordlist')
 HISTOGRAM_ALIASES = ('hist' , 'histogram' , 'statgram')
 SCRAPER_ALIASES = ('scraper' , 'scrape' , 'scrape-page')
+SNOWFLAKE_ALIASES = ('explain' , 'snowflake' , 'snowflake-explain')
 
 DBCursor = cfg.DBCursor 
  
@@ -50,6 +51,7 @@ def arguments(args : list = None):
     restore = p.add_parser(RESTORE_ALIASES[0] , help = 'Restore the database from a backup file' , aliases = RESTORE_ALIASES[1:])
     histogram = p.add_parser(HISTOGRAM_ALIASES[0] , help = 'Make a histogram of a wordlist' , aliases = HISTOGRAM_ALIASES[1:])
     scraper = p.add_parser(SCRAPER_ALIASES[0] , help = 'Scrape a webpage for words' , aliases = SCRAPER_ALIASES[1:])
+    explain_snowflake = p.add_parser(SNOWFLAKE_ALIASES[0] , help = 'Explains the Snowflake flag' , aliases = SNOWFLAKE_ALIASES[1:])
     
     for _parser in (edit ,  freeze , copy , histogram , scraper):
         _parser.add_argument(dest = 'wordlist' , choices = cfg.Wordlists,  help = 'The wordlist to use' )
@@ -171,6 +173,9 @@ def recount(wordlist ):
     logger.info(f'Recount successfully completed')
     count = DBCursor.execute(f'SELECT COUNT(counter) FROM {wordlist}').fetchone()[0]
     logger.info(f'TOTAL WORDS in {wordlist}::{count}')
+    
+    
+    
     DBCursor.executescript(f'begin;UPDATE wordlists SET total_words = {count}, updated_at = CURRENT_TIMESTAMP WHERE name = "{wordlist}";commit;')
     return count 
     
@@ -213,11 +218,14 @@ def create(wordlist , file , words , description : str = None ) :
                     
                     
         if words is not None:
-            cfg.DBCursor.executemany(f'INSERT INTO {wordlist} (word) VALUES (?)' , [[word] for word in words])
         
-        if len(words) == 0 :
-            
-            logger.warning(f'Since -w was passed but no words were provided, it is assumed that the purpose is to create a wordlist without any words')
+            if len(words) == 0 :
+                
+                logger.warning(f'Since -w was passed but no words were provided, it is assumed that the purpose is to create a wordlist without any words')
+
+            else:
+                cfg.DBCursor.executemany(f'INSERT INTO {wordlist} (word) VALUES (?)' , [[word] for word in words])
+        
             
         count = cfg.DBCursor.execute(f'SELECT COUNT(*) FROM {wordlist}').fetchone()[0]
         cfg.DBCursor.execute('''UPDATE 
@@ -490,6 +498,31 @@ def freeze(wordlist , output):
 
 def DriverMain(options : Namespace):
     
+    if options.action in SNOWFLAKE_ALIASES:
+        
+        file = os.path.join(cfg.ProgPath , 'snowflake.md')
+        data = open(file , 'r' , encoding = 'utf8').read()
+        
+        try:
+            from rich.console import Console
+            from rich.markdown import Markdown
+            
+            logger.info(f'Open `{file}` or `{file.replace(".md" , ".pdf")}` files to read more on the snowflake flag')
+            console = Console()
+            md = Markdown(data)
+            console.print(md)
+             
+        except ImportError:
+            
+            logger.error(f'Open `{file}` or `{file.replace(".md" , ".pdf")}` files to read more on the snowflake flag')
+            print(data)
+            
+        except:
+            
+            raise 
+    
+        return None 
+            
     if options.action in GENERATE_ALIASES:
         
         logger.info('Executing CREATE')
